#!/usr/bin/env bash
#
# Filename: get-all-updates.bash (ESR version)
#
# Copyright (C) 2016-2018 Hartmut Buhrmester
#                         <zo3xaiD8-eiK1iawa@t-online.de>
#
# License
#
#     This file is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published
#     by the Free Software Foundation, either version 3 of the License,
#     or (at your option) any later version.
#
#     This file is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#     General Public License for more details.
#
#     You should have received a copy of the GNU General
#     Public License along with this program.  If not, see
#     <http://www.gnu.org/licenses/>.
#
# Description
#
#     This is an example script to download all updates for the
#     languages German and English. These are the default languages
#     for the Windows script DownloadUpdates.cmd. For the Linux script
#     download-updates.bash, all needed languages must be listed on the
#     command line. Since version 1.0-beta-4, you can combine several
#     languages to a comma-separated list.
#
#     It may also serve as a template to be customized.


# Stop this script, if one of download runs exits with an error code.
set -o errexit

# Resolving the installation path with GNU readlink is very reliable,
# but it may only work in Linux and FreeBSD. Remove the option -f for
# BSD readlink on Mac OS X. If there are any problems with resolving
# the installation path, change directly to the installation directory
# of this script and run it from there.
cd "$(dirname "$(readlink -f "$0")")"


# Download using internal lists
#
# Using the internal list "all" is a simple way to get all updates for
# all supported Windows and Office versions:

./download-updates.bash all deu,enu -includesp -includecpp -includedotnet -includewddefs -includemsse


# The remaining examples demonstrate, which optional downloads are
# available for each update. They are all commented out, so that they
# won't be called twice.


# Note: Use the current version of WSUS Offline Update for:
# - the server versions of Windows Vista and 8 (Windows Server 2008 and
#   2012), since they are still supported
# - Windows 7, 8.1, and 10, including their server versions
# - Office 2010 - 2016


# Windows XP
#
# Updates for Windows XP and Server 2003 are localized. Specify all
# languages you need. For better comparison with the Windows script
# DownloadUpdates.cmd, the default languages German and English are
# listed here.

# ./download-updates.bash wxp deu,enu -includesp -includecpp -includedotnet -includewddefs -includemsse


# Windows Server 2003
#
# Microsoft Security Essentials are not supported by Windows Server 2003.

# ./download-updates.bash w2k3,w2k3-x64 deu,enu -includesp -includecpp -includedotnet -includewddefs


# Windows Vista (desktop versions)
#
# Setting the language is needed to get localized installers for Internet
# Explorer 9 for Windows Vista, and for the optional downloads dotnet
# and msse.

# ./download-updates.bash w60,w60-x64 deu,enu -includesp -includecpp -includedotnet -includewddefs -includemsse


# Windows 8 (desktop versions)
#
# Updates for Windows 8 to 10 are really global, und they are only
# evaluated once for all specified languages. The language parameters
# deu and enu are still needed for the .Net Framework downloads. Without
# this optional download, one language (any one) would be sufficient.
#
# To be precise, the English installers for .Net Frameworks are always
# downloaded, and they are supplemented by language packs for other
# languages. So, you could actually remove the parameter "enu" here. On
# the other hand, if you like to include other "custom" languages,
# they need to be listed here.

# ./download-updates.bash w62,w62-x64 deu,enu -includesp -includecpp -includedotnet -includewddefs8


# Office 2003 and 2007

# ./download-updates.bash o2k3,o2k7 deu,enu -includesp

exit 0
